<?
/*
*******************************
 IP-SYMCON Event Scripting
*******************************
File     : LCD_Beispiel.ips.php
Trigger  : 
Interval :
Author   : HJH
Project  : NanoTerminal
Date     : 20.11.08
*/

//******************************************************************************
// Erzeugung eines LCD-Objekts
// ===========================
//
// Das Script "LCD_Functions.ips.php" muss eingebunden sein,
// entweder durch "include" oder durch "require".
//
// $InstanceID: InstanceID des fr das LCD verwendeten 1-Wire Bausteins
//
// Zulssige Werte fr $ControllerType:
// $ControllerType = "Standard";
// $ControllerType = "KS0073";
// $ControllerType = "ST7036";
//
// $Zeilen: Anzahl der LCD-Zeilen
// $Spalten: Anzahl der Zeichen pro Zeile
//
// Alle Ports des 1-Wire Bausteins DS2408 mssen in der Instance-Definition
// ihrer Funktion entsprechend als Ein- oder Ausgang deklariert werden.
// Fr das NanoTerminal gilt:
// P0...P4: Output (LCD-Daten)
// P5...P6: Input  (zB. fr Tasten)
// P7:      Output (Summer)
//
//******************************************************************************
// die folgenden Angaben mssen angepasst werden:
//$InstanceID = 15630;
//$InstanceID = 25945;
//$InstanceID = 55256;
//$InstanceID = 15059;
//$InstanceID = 16023;
//$InstanceID = 17124;
//$InstanceID = 28581;
$InstanceID = 34126;
//$lcdnr = 2;
//$ControllerType = "ST7036";
$ControllerType = "KS0073";
$Zeilen = 4;
$Spalten = 20;

// Erzeugung des LCD-Objekts (wird hier durch die Variable $lcd reprsentiert)
require_once ".\\LCD_Functions.ips.php";
//$lcd = new OneWireLCD($InstanceID, $ControllerType, $Zeilen, $Spalten, $lcdnr);
$lcd = new OneWireLCD($InstanceID, $ControllerType, $Zeilen, $Spalten);



//******************************************************************************
// LCD-Initialisierung
// ===================
//
// Diese Funktion muss nur jeweils einmal
// nach dem Einschalten oder einem Reset aufgerufen werden
//
//******************************************************************************
$lcd->SendLCDInit();



//******************************************************************************
// LCD-Textausgabe auf das gesamte Display
// =======================================
//
// Die einzelnen Zeilen sind durch "|" voneinander getrennt.
//
//******************************************************************************
//return;
if ($ControllerType == "ST7036")
 $text = "IP-Symcon| Strae ||letzte Zeile";
else
// $text = "IP-Symcon|NanoTerminal||letzte Zeile";
 $text = "IP-Symcon| Strae ||letzte Zeile";
$lcd->SendLCDScreen($text);



//******************************************************************************
// LCD-Textausgabe an einer bestimmten Cursor-Position
// ===================================================
//
// Zeilenberlauf wird nicht bercksichtigt!
//
//******************************************************************************
//return;
$text = date("d.m.y H:i");
$lcd->SendLCDText(2, 1, $text); // 3. Zeile, 2. Spalte



//******************************************************************************
// Kontrasteinstellung beim ST7036 Controller
// ==========================================
//
// Diese Funktion ist beim Standard-Controller nicht verfgbar
//
// Zulssige Werte fr $ContrastValue: 0...63
//
//******************************************************************************
//return;
$ContrastValue = 38;
$lcd->SendLCDContrast($ContrastValue);



//******************************************************************************
// Symbole beim KS0073 Controller anzeigen
// =======================================
//
// Diese Funktion ist nur beim KS0073-Controller verfgbar
//
// Zulssige Werte fr $Symbol: 0...15
//
//******************************************************************************
//return;
$Symbol = 14;
$lcd->SendLCDSymbol($Symbol, true, false);   // Symbol, anzeigen, blinken



//******************************************************************************
// Definition eigener Zeichen
// ==========================
//
// Es ist mglich 8 Zeichen zu definieren (Speicherposition 0...7).
// Die Zeichen werden in einer 5x8 Matrix dargestellt.
// Es sind also fr jedes Zeichen 8 Bytes zu bergeben, von denen jeweils die
// niederwertigen 5 Bits verwendet werden.
// Ein gesetztes Bit reprsentiert dabei einen sichbaren Punkt.
// Das erste Byte stellt die oberste Zeichenzeile dar, das letzte die unterste.
//
//******************************************************************************
//return;
$backslash = "\x00\x10\x08\x04\x02\x01\x00\x00";
// abspeichern an Speicherposition 0
$lcd->SendLCDCharDef(0, $backslash);
// Ausgabe des Zeichens in Position 0
$lcd->SendLCDText(0, 12, "\x00"); // 1. Zeile, 13. Spalte
/*
$box = "\x1f\x11\x11\x11\x11\x11\x11\x1f";
// abspeichern an Speicherposition 1
$lcd->SendLCDCharDef(1, $box);
// Ausgabe des Zeichens in Position 1
$lcd->SendLCDText(0, 13, "\x01"); // 1. Zeile, 14. Spalte

$checker = "\x15\x0a\x15\x0a\x15\x0a\x15\x0a";
// abspeichern an Speicherposition 2
$lcd->SendLCDCharDef(2, $checker);
// Ausgabe des Zeichens in Position 2
$lcd->SendLCDText(0, 14, "\x02C"); // 1. Zeile, 15. Spalte

$degree = "\x06\x09\x09\x06\x00\x00\x00\x00";
// abspeichern an Speicherposition 3
$lcd->SendLCDCharDef(3, $degree);
// Ausgabe des Zeichens in Position 3
$lcd->SendLCDText(0, 15, "\x03C"); // 1. Zeile, 16. Spalte
*/


//******************************************************************************
// Gimmick: rotierender Balken
// ===========================
//
// Der folgende String ($motion) enthlt 4 Zeichen:
// 1. "|"
// 2. "/"
// 3. "-"
// 4. "\x00" Dies ist das selbst definierte Zeichen an Speicherposition 0,
//           in diesem Falle also ein Backslash.
//
//******************************************************************************
return;
$motion = "|/-\x00";
IPS_Sleep(1000);
for ($i=0; $i<50; $i++)
{
 $s = substr($motion, $i%4, 1);
 $lcd->SendLCDText(0, 10, $s); // 1. Zeile, 11. Spalte
 IPS_Sleep(100);
}
?>
